camelot.camelot.types.IPAddress

Package camelot :: Package camelot :: Package types :: Class IPAddress |
[hide private]
[frames] | no frames]

# Class IPAddress

source code

Instance Methods | [hide private]
__init__(self, **kwargs) | source code
Inherited from `Code`: `bind_processor`, `result_processor`

Class Variables | [hide private]
Inherited from `Code`: `impl`

Method Details | [hide private]

### __init__(self, **kwargs) (Constructor) | source code
Parameters: `parts` - a list of input masks specifying the mask for each part, eg ['99', 'AA'], for valid input masks, see the docs of qlineedit Overrides: Code.__init__